@@ -4,6 +4,8 @@
 #  - Request trading
 # Negative cache
 # Max-age cache
+# Remove dateutil/req from pagegetter
+# Remove pytz/req from pagegetter
 
 from twisted.python.failure import Failure
 
@@ -759,15 +761,16 @@ class AWSpider:
         reactor.callLater( 1, reactor.stop )
     
     def coordinate( self ):
-        print "Peers: %s" % self.peers
+        logger.debug( "Peers: %s" % self.peers )
         attributes = { "created":sdb_now(offset=self.time_offset) }
         attributes.update( self.network_information )
         self.sdb.putAttributes( self.aws_sdb_coordination_domain, self.uuid, attributes, replace=attributes.keys() )
         reactor.callLater( 5, self.checkPeers )
     
     def checkPeers( self ):
+        logger.debug( sdb_now( offset=self.time_offset) )
         sql = "SELECT public_ip, local_ip, port FROM %s WHERE created > '%s'" % ( self.aws_sdb_coordination_domain, sdb_now_add( self.peer_check_interval * -2, offset=self.time_offset) )
-        #logger.debug( "Querying SimpleDB, \"%s\"" % sql )
+        logger.debug( "Querying SimpleDB, \"%s\"" % sql )
         d = self.sdb.select( sql )
         d.addCallback( self._checkPeersCallback )
         d.addErrback( self._checkPeersErrback )
